@@ -13,6 +13,21 @@ def to_camel_case(input_dict):
             new_dict[parsed_key] = value
     return new_dict
 
+def to_snake_case(input_dict):
+    """
+    Converts a dict with keys in camel case to dict with keys
+    in snake case
+    """
+    new_dict = {}
+    if isinstance(input_dict, dict):
+        for key, value in input_dict.items():
+            parsed_key = camel_to_snake_case(key)
+            new_dict[parsed_key] = value
+    return new_dict
+
+def camel_to_snake_case(string):
+   return re.sub(r'(?<!^)(?=[A-Z])', '_', string).lower()
+
 def camelize(key):
     parts = iter(key.split("_"))
     return next(parts) + "".join(i.title() for i in parts)
